==> katapult-trinity_3.5.13.2.orig.tar.xz: katapult-trinity-3.5.13.2/katapult/plugins/catalogs/bookmarkcatalog/bookmark.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include <kbookmark.h>
#include <kglobal.h>
#include <kiconloader.h>

#include "bookmark.h"

Bookmark::Bookmark(KBookmark _bookmark)
 : KatapultItem()
{
	this->_bookmark = _bookmark;
}

TQPixmap Bookmark::icon(int size) const
{
	return KGlobal::iconLoader()->loadIcon(_bookmark.icon(), KIcon::NoGroup, size);
}

KBookmark Bookmark::bookmark() const
{
	return _bookmark;
}

TQString Bookmark::text() const
{
	return _bookmark.text();
}

#include "bookmark.moc"

==> katapult-trinity-14.1.5.tar.xz: katapult-trinity-14.1.5/katapult/plugins/catalogs/bookmarkcatalog/bookmark.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include <kbookmark.h>
#include <tdeglobal.h>
#include <kiconloader.h>

#include "bookmark.h"

Bookmark::Bookmark(KBookmark _bookmark)
 : KatapultItem()
{
	this->_bookmark = _bookmark;
}

TQPixmap Bookmark::icon(int size) const
{
	return TDEGlobal::iconLoader()->loadIcon(_bookmark.icon(), TDEIcon::NoGroup, size);
}

KBookmark Bookmark::bookmark() const
{
	return _bookmark;
}

TQString Bookmark::text() const
{
	return _bookmark.text();
}

#include "bookmark.moc"
